@@ -486,3 +486,133 @@ class ManeDataService(BaseModelForbidExtra):
                     "url": "https://github.com/GenomicMedLab/cool-seq-tool"
                 }
             }
+
+
+# ALIGNMENT MAPPER SERVICE SCHEMAS
+
+
+class CdnaRepresentation(BaseModelForbidExtra):
+    """Model response for cDNA representation"""
+
+    c_ac: str
+    c_start_pos: str
+    c_end_pos: str
+    cds_start: int
+    residue_mode = ResidueMode.INTER_RESIDUE.value
+
+    class Config(BaseModelForbidExtra.Config):
+        """Configure model."""
+
+        @staticmethod
+        def schema_extra(schema: Dict[str, Any],
+                         model: Type["CdnaRepresentation"]) -> None:
+            """Configure OpenAPI schema."""
+            if "title" in schema.keys():
+                schema.pop("title", None)
+            for prop in schema.get("properties", {}).values():
+                prop.pop("title", None)
+            schema["example"] = {
+                "c_ac": "NM_004333.6",
+                "c_start_pos": 1797,
+                "c_end_pos": 1800,
+                "cds_start": 226,
+                "residue_mode": "inter-residue"
+            }
+
+
+class ToCdnaService(BaseModelForbidExtra):
+    """Service model response for protein -> cDNA"""
+
+    c_data: Optional[CdnaRepresentation] = None
+    warnings: List[StrictStr] = []
+    service_meta: ServiceMeta
+
+    class Config(BaseModelForbidExtra.Config):
+        """Configure model."""
+
+        @staticmethod
+        def schema_extra(schema: Dict[str, Any],
+                         model: Type["ToCdnaService"]) -> None:
+            """Configure OpenAPI schema."""
+            if "title" in schema.keys():
+                schema.pop("title", None)
+            for prop in schema.get("properties", {}).values():
+                prop.pop("title", None)
+            schema["example"] = {
+                "c_data": {
+                    "c_ac": "NM_004333.6",
+                    "c_start_pos": 1797,
+                    "c_end_pos": 1800,
+                    "cds_start": 226,
+                    "residue_mode": "inter-residue"
+                },
+                "warnings": list(),
+                "service_meta": {
+                    "name": "cool_seq_tool",
+                    "version": __version__,
+                    "response_datetime": datetime.now(),
+                    "url": "https://github.com/GenomicMedLab/cool-seq-tool"
+                }
+            }
+
+
+class GenomicRepresentation(BaseModelForbidExtra):
+    """Model response for genomic representation"""
+
+    g_ac: str
+    g_start_pos: int
+    g_end_pos: int
+    residue_mode = ResidueMode.INTER_RESIDUE.value
+
+    class Config(BaseModelForbidExtra.Config):
+        """Configure model."""
+
+        @staticmethod
+        def schema_extra(schema: Dict[str, Any],
+                         model: Type["CdnaRepresentation"]) -> None:
+            """Configure OpenAPI schema."""
+            if "title" in schema.keys():
+                schema.pop("title", None)
+            for prop in schema.get("properties", {}).values():
+                prop.pop("title", None)
+            schema["example"] = {
+                "g_ac": "NC_000007.13",
+                "g_start_pos": 140453134,
+                "g_end_pos": 140453137,
+                "residue_mode": "inter-residue"
+            }
+
+
+class ToGenomicService(BaseModelForbidExtra):
+    """Service model response for cDNA -> genomic"""
+
+    g_data: Optional[GenomicRepresentation] = None
+    warnings: List[StrictStr] = []
+    service_meta: ServiceMeta
+
+    class Config(BaseModelForbidExtra.Config):
+        """Configure model."""
+
+        @staticmethod
+        def schema_extra(schema: Dict[str, Any],
+                         model: Type["ToGenomicService"]) -> None:
+            """Configure OpenAPI schema."""
+            if "title" in schema.keys():
+                schema.pop("title", None)
+            for prop in schema.get("properties", {}).values():
+                prop.pop("title", None)
+            schema["example"] = {
+                "g_data": {
+                    "g_ac": "NC_000007.13",
+                    "g_start_pos": 140453134,
+                    "g_end_pos": 140453137,
+                    "residue_mode": "inter-residue"
+                },
+                "warnings": list(),
+                "service_meta": {
+                    "name": "cool_seq_tool",
+                    "version": __version__,
+                    "response_datetime": datetime.now(),
+                    "url": "https://github.com/GenomicMedLab/cool-seq-tool"
+                }
+            }
